@@ -1226,8 +1226,8 @@ END
    sleep 5;
 
    ($stdout,$stderr)=$handle->cmd($sudo.
-      'wget -qO- https://pigeonhole.dovecot.org/download.html');
-   $stdout=~s/^.*?Download [<]a href=["]([^"]+)?["][>].*$/$1/s;
+      'wget -qO- https://dovecot.org/download');
+   $stdout=~s/^.*?EOL statement.*?[<]a href=["]([^"]+)?["]\s.*$/$1/s;
    my $gtarfile=$stdout;
    ($stdout,$stderr)=$handle->cmd($sudo.
       "wget --random-wait --progress=dot ".$stdout,
@@ -1237,12 +1237,17 @@ END
       "tar zxvf $gtarfile",'__display__');
    $gtarfile=~s/.tar.gz$//;
    ($stdout,$stderr)=$handle->cwd($gtarfile);
+   #($stdout,$stderr)=$handle->cmd($sudo.
+   #   'mkdir -vp /usr/local/etc','__display__');
+   #($stdout,$stderr)=$handle->cmd($sudo.
+   #   'cp -r doc/dovecot/example-config/* /usr/local/etc/dovecot/',
+   #   '__display__');
    ($stdout,$stderr)=$handle->cmd($sudo.
       "./configure",'__display__');
    ($stdout,$stderr)=$handle->cmd($sudo.
-      "./make",'__display__');
+      "make",'__display__');
    ($stdout,$stderr)=$handle->cmd($sudo.
-      "./make install",'__display__');
+      "make install",'__display__');
 
    #
    # echo-ing/streaming files over ssh can be tricky. Use echo -e
@@ -1785,7 +1790,7 @@ END
          '--enable-xmlwriter '.
          '--with-zip '.
          '--with-zlib','__display__');
-      ($stdout,$stderr)=$handle->cmd($sudo.'make -j2','__display__');
+      ($stdout,$stderr)=$handle->cmd($sudo.'make -j2',300,'__display__');
       ($stdout,$stderr)=$handle->cmd($sudo.'make install','__display__');
       ($stdout,$stderr)=$handle->cmd($sudo.
          'ln -s /usr/local/php7/bin/php /usr/local/bin/php');
@@ -1930,7 +1935,6 @@ END
       ($stdout,$stderr)=$handle->cmd($sudo.
          "/etc/init.d/ea-php70-php-fpm start",'__display__');
    }
-}
 
    # http://www.theblogmaven.com/best-emailserver-plugins/
 
